%% Display program for IINPP TNG5
%%
%-----------------------------------------------------------|
% [ ] = plot_tng5( path, kernel, start_time )
%-----------------------------------------------------------|
%
% INPUT:
% path          [*x1] [-] [str]  Data directory path
% kernel        [*xn] [-] [str]  Data filename kernel
% start_time    [1x1] [s] [dbl]  Used for x-axis labeling
%
% OUTPUT:
% None
%
% DESCRIPTION:
% This function calls multile plot functions required for
% displaying TNG5 processing results.
%
% REFERENCES:
% None
%
% COPYRIGHT © 2011 Applanix Corporation. All rights reserved.

% CHANGE LOG
% 2011-Dec-02; J. Traugott; Changed script to function

function [ ] = plot_tng5( path, kernel, start_time  )

%% Input checks

% Make sure that there is an end backslash
if path(end) ~= '\'
  path = strcat( path, '\' );
end

%% Call TNG5 display functions

% AINS navigation solution

plot_veh_nav_soln('start',path,kernel,start_time);

% Kinematic Ambiguity Resolution (KAR) data

plot_kar_data('start',path,kernel,start_time);

% GAMS data

plot_gams_data('start',path,kernel,start_time);

% GNSS track data

plot_gnss_track_data('start',path,kernel,start_time);

% IIN KF inertial navigator error states (N1)

plot_iin_kf_state('start',path,kernel,start_time);
 
% IIN KF inertial navigator error estimation standard deviations (N1)

plot_iin_kf_state_sd('start',path,kernel,start_time);

% IIN KF inertial sensor error states with SD envelopes N2-N5

plot_iin_kf_state_sd_env('start',path,kernel,start_time);

% IIN KF measurements

plot_iin_kf_meas_data('start',path,kernel,start_time);

% IIN KF measurement standard deviations

plot_iin_kf_meas_sd('start',path,kernel,start_time);

% IIN KF measurement residuals with SD envelopes

plot_iin_kf_meas_sd_env('start',path,kernel,start_time);

% SNV a priori primary antenna position and Astra position change

plot_snv_pri_gnss_pos('start',path,kernel,start_time);

% Primary GNSS antenna position from Astra engine

plot_astra_gnss_nav('start',path,kernel,start_time);

% Navigation differences

plot_snv_navdif_data('start',path,kernel,start_time);
    
plot_gnss_navdif_data('start',path,kernel,start_time);
    
end
